@@ -562,7 +562,7 @@ unsafe extern "C" fn video_decoder_open<T: VideoDecoderImpl>(
     let imp = instance.impl_();
     let wrap: Borrowed<VideoDecoder> = from_glib_borrow(ptr);
 
-    gst::panic_to_error!(&wrap, &imp.panicked(), false, {
+    gst::panic_to_error!(&wrap, imp.panicked(), false, {
         match imp.open(wrap.unsafe_cast_ref()) {
             Ok(()) => true,
             Err(err) => {
@@ -581,7 +581,7 @@ unsafe extern "C" fn video_decoder_close<T: VideoDecoderImpl>(
     let imp = instance.impl_();
     let wrap: Borrowed<VideoDecoder> = from_glib_borrow(ptr);
 
-    gst::panic_to_error!(&wrap, &imp.panicked(), false, {
+    gst::panic_to_error!(&wrap, imp.panicked(), false, {
         match imp.close(wrap.unsafe_cast_ref()) {
             Ok(()) => true,
             Err(err) => {
@@ -600,7 +600,7 @@ unsafe extern "C" fn video_decoder_start<T: VideoDecoderImpl>(
     let imp = instance.impl_();
     let wrap: Borrowed<VideoDecoder> = from_glib_borrow(ptr);
 
-    gst::panic_to_error!(&wrap, &imp.panicked(), false, {
+    gst::panic_to_error!(&wrap, imp.panicked(), false, {
         match imp.start(wrap.unsafe_cast_ref()) {
             Ok(()) => true,
             Err(err) => {
@@ -619,7 +619,7 @@ unsafe extern "C" fn video_decoder_stop<T: VideoDecoderImpl>(
     let imp = instance.impl_();
     let wrap: Borrowed<VideoDecoder> = from_glib_borrow(ptr);
 
-    gst::panic_to_error!(&wrap, &imp.panicked(), false, {
+    gst::panic_to_error!(&wrap, imp.panicked(), false, {
         match imp.stop(wrap.unsafe_cast_ref()) {
             Ok(()) => true,
             Err(err) => {
@@ -638,7 +638,7 @@ unsafe extern "C" fn video_decoder_finish<T: VideoDecoderImpl>(
     let imp = instance.impl_();
     let wrap: Borrowed<VideoDecoder> = from_glib_borrow(ptr);
 
-    gst::panic_to_error!(&wrap, &imp.panicked(), gst::FlowReturn::Error, {
+    gst::panic_to_error!(&wrap, imp.panicked(), gst::FlowReturn::Error, {
         imp.finish(wrap.unsafe_cast_ref()).into()
     })
     .into_glib()
@@ -651,7 +651,7 @@ unsafe extern "C" fn video_decoder_drain<T: VideoDecoderImpl>(
     let imp = instance.impl_();
     let wrap: Borrowed<VideoDecoder> = from_glib_borrow(ptr);
 
-    gst::panic_to_error!(&wrap, &imp.panicked(), gst::FlowReturn::Error, {
+    gst::panic_to_error!(&wrap, imp.panicked(), gst::FlowReturn::Error, {
         imp.drain(wrap.unsafe_cast_ref()).into()
     })
     .into_glib()
@@ -667,7 +667,7 @@ unsafe extern "C" fn video_decoder_set_format<T: VideoDecoderImpl>(
     ffi::gst_video_codec_state_ref(state);
     let wrap_state = VideoCodecState::<Readable>::new(state);
 
-    gst::panic_to_error!(&wrap, &imp.panicked(), false, {
+    gst::panic_to_error!(&wrap, imp.panicked(), false, {
         match imp.set_format(wrap.unsafe_cast_ref(), &wrap_state) {
             Ok(()) => true,
             Err(err) => {
@@ -693,7 +693,7 @@ unsafe extern "C" fn video_decoder_parse<T: VideoDecoderImpl>(
     let wrap_adapter: Borrowed<gst_base::Adapter> = from_glib_borrow(adapter);
     let at_eos: bool = from_glib(at_eos);
 
-    gst::panic_to_error!(&wrap, &imp.panicked(), gst::FlowReturn::Error, {
+    gst::panic_to_error!(&wrap, imp.panicked(), gst::FlowReturn::Error, {
         imp.parse(wrap.unsafe_cast_ref(), &wrap_frame, &wrap_adapter, at_eos)
             .into()
     })
@@ -709,7 +709,7 @@ unsafe extern "C" fn video_decoder_handle_frame<T: VideoDecoderImpl>(
     let wrap: Borrowed<VideoDecoder> = from_glib_borrow(ptr);
     let wrap_frame = VideoCodecFrame::new(frame, &*wrap);
 
-    gst::panic_to_error!(&wrap, &imp.panicked(), gst::FlowReturn::Error, {
+    gst::panic_to_error!(&wrap, imp.panicked(), gst::FlowReturn::Error, {
         imp.handle_frame(wrap.unsafe_cast_ref(), wrap_frame).into()
     })
     .into_glib()
@@ -722,7 +722,7 @@ unsafe extern "C" fn video_decoder_flush<T: VideoDecoderImpl>(
     let imp = instance.impl_();
     let wrap: Borrowed<VideoDecoder> = from_glib_borrow(ptr);
 
-    gst::panic_to_error!(&wrap, &imp.panicked(), false, {
+    gst::panic_to_error!(&wrap, imp.panicked(), false, {
         VideoDecoderImpl::flush(imp, wrap.unsafe_cast_ref())
     })
     .into_glib()
@@ -735,7 +735,7 @@ unsafe extern "C" fn video_decoder_negotiate<T: VideoDecoderImpl>(
     let imp = instance.impl_();
     let wrap: Borrowed<VideoDecoder> = from_glib_borrow(ptr);
 
-    gst::panic_to_error!(&wrap, &imp.panicked(), false, {
+    gst::panic_to_error!(&wrap, imp.panicked(), false, {
         match imp.negotiate(wrap.unsafe_cast_ref()) {
             Ok(()) => true,
             Err(err) => {
@@ -755,7 +755,7 @@ unsafe extern "C" fn video_decoder_getcaps<T: VideoDecoderImpl>(
     let imp = instance.impl_();
     let wrap: Borrowed<VideoDecoder> = from_glib_borrow(ptr);
 
-    gst::panic_to_error!(&wrap, &imp.panicked(), gst::Caps::new_empty(), {
+    gst::panic_to_error!(&wrap, imp.panicked(), gst::Caps::new_empty(), {
         VideoDecoderImpl::caps(
             imp,
             wrap.unsafe_cast_ref(),
@@ -775,7 +775,7 @@ unsafe extern "C" fn video_decoder_sink_event<T: VideoDecoderImpl>(
     let imp = instance.impl_();
     let wrap: Borrowed<VideoDecoder> = from_glib_borrow(ptr);
 
-    gst::panic_to_error!(&wrap, &imp.panicked(), false, {
+    gst::panic_to_error!(&wrap, imp.panicked(), false, {
         imp.sink_event(wrap.unsafe_cast_ref(), from_glib_full(event))
     })
     .into_glib()
@@ -789,7 +789,7 @@ unsafe extern "C" fn video_decoder_sink_query<T: VideoDecoderImpl>(
     let imp = instance.impl_();
     let wrap: Borrowed<VideoDecoder> = from_glib_borrow(ptr);
 
-    gst::panic_to_error!(&wrap, &imp.panicked(), false, {
+    gst::panic_to_error!(&wrap, imp.panicked(), false, {
         imp.sink_query(wrap.unsafe_cast_ref(), gst::QueryRef::from_mut_ptr(query))
     })
     .into_glib()
@@ -803,7 +803,7 @@ unsafe extern "C" fn video_decoder_src_event<T: VideoDecoderImpl>(
     let imp = instance.impl_();
     let wrap: Borrowed<VideoDecoder> = from_glib_borrow(ptr);
 
-    gst::panic_to_error!(&wrap, &imp.panicked(), false, {
+    gst::panic_to_error!(&wrap, imp.panicked(), false, {
         imp.src_event(wrap.unsafe_cast_ref(), from_glib_full(event))
     })
     .into_glib()
@@ -817,7 +817,7 @@ unsafe extern "C" fn video_decoder_src_query<T: VideoDecoderImpl>(
     let imp = instance.impl_();
     let wrap: Borrowed<VideoDecoder> = from_glib_borrow(ptr);
 
-    gst::panic_to_error!(&wrap, &imp.panicked(), false, {
+    gst::panic_to_error!(&wrap, imp.panicked(), false, {
         imp.src_query(wrap.unsafe_cast_ref(), gst::QueryRef::from_mut_ptr(query))
     })
     .into_glib()
@@ -832,7 +832,7 @@ unsafe extern "C" fn video_decoder_propose_allocation<T: VideoDecoderImpl>(
     let wrap: Borrowed<VideoDecoder> = from_glib_borrow(ptr);
     let query = gst::QueryRef::from_mut_ptr(query);
 
-    gst::panic_to_error!(&wrap, &imp.panicked(), false, {
+    gst::panic_to_error!(&wrap, imp.panicked(), false, {
         match imp.propose_allocation(wrap.unsafe_cast_ref(), query) {
             Ok(()) => true,
             Err(err) => {
@@ -853,7 +853,7 @@ unsafe extern "C" fn video_decoder_decide_allocation<T: VideoDecoderImpl>(
     let wrap: Borrowed<VideoDecoder> = from_glib_borrow(ptr);
     let query = gst::QueryRef::from_mut_ptr(query);
 
-    gst::panic_to_error!(&wrap, &imp.panicked(), false, {
+    gst::panic_to_error!(&wrap, imp.panicked(), false, {
         match imp.decide_allocation(wrap.unsafe_cast_ref(), query) {
             Ok(()) => true,
             Err(err) => {
